#
# spec file for package pptp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pptp
Version:        1.8.0
Release:        lp150.1.10
Summary:        Point-to-Point Tunneling Protocol (PPTP) Client
License:        GPL-2.0+
Group:          Productivity/Networking/Security
Url:            http://pptpclient.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/pptpclient/pptp/pptp-%{version}/%{name}-%{version}.tar.gz
Source1:        pptp-command
Source2:        options.pptp
Source3:        pptp_fe.pl
Source4:        xpptp_fe.pl
Patch1:         pptp-makefile.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A client for the proprietary Microsoft Point-to-Point Tunneling
Protocol, PPTP.  It allows connections to a PPTP based VPN as used by
employers and some cable and ADSL service providers. It requires MPPE
support in the kernel. Use the ppp-mppe package.

%prep
%setup -q
%patch1

%build
make CFLAGS="%{optflags}"

%install
make install DESTDIR=%{buildroot}

mkdir -p %{buildroot}%{_sysconfdir}/ppp
mkdir -p %{buildroot}%{_sysconfdir}/pptp.d

cp %{SOURCE1} %{buildroot}%{_sbindir}/pptp-command
cp %{SOURCE2} %{buildroot}%{_sysconfdir}/ppp

find Documentation	-name CVS | xargs rm -rf
find Reference		-name CVS | xargs rm -rf

%files
%defattr(0644,root,root,0755)
%doc AUTHORS COPYING NEWS README TODO USING Documentation
%attr(0755,root,root) %{_sbindir}/pptp
%attr(0755,root,root) %{_sbindir}/pptpsetup
%attr(0444,root,root) %{_mandir}/man8/pptp.8.gz
%attr(0444,root,root) %{_mandir}/man8/pptpsetup.8.gz
%attr(0755,root,root) %{_sbindir}/pptp-command
%attr(750, root, root) %dir %{_sysconfdir}/ppp
%config %attr(0600,root,root) %{_sysconfdir}/ppp/options.pptp
%attr(0755,root,root) %{_sysconfdir}/pptp.d

%changelog
* Tue Jun 13 2017 kukuk@suse.de
- Add /etc/ppp directory
* Thu Mar 12 2015 p.drouand@gmail.com
- Update to version 1.8.0
  * options file, fix option documentation and links
  * fix many warnings
  * fix parallel build failure
  * fix call disconnect notify
  * add --n*hostroute option to disable routing calls
  * add --rtmark option for Linux policy routing
  * move free of conn struct out of main loop
  * avoid using conn struct after it is freed
  * correct response to call disconnect notify
  * avoid superfluous MPPE capability checks in pptpsetup
  * retain permissions on chap-secrets, closes rhbz#492090
  * compilation fixes for older distributions of Linux
  * port routing change feature for Solaris
  * add IP_BINARY
  * add include file build dependencies
* Mon Apr 15 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, https://en.opensuse.org/SourceUrls
* Tue Sep 29 2009 max@suse.de
- Change 'pptp-command stop' to kill pppd instead of pptp to fix
  an cleanup tunnel shutdown (bnc#536225).
* Fri Jul  4 2008 hvogel@suse.de
- update to version 1.7.2
  * new --test-type and --test-rate options
  * implement reordering tests to assist with pptpd testing
  * when we fail to write due to a transient error
    simply ignore it (treat it as a drop).
  * add route to PPTP server.  Experimental feature.
  * include pptpsetup in kit
  * remove Reference documentation as the license is non-free.
  * add refuse-pap to default options
* Thu Nov  2 2006 hvogel@suse.de
- launder route variable in pptp-command (taint mode) [#214627]
* Mon Oct 23 2006 hvogel@suse.de
- update to version 1.7.1
  * use prctl(2) to set process name
  * remove superfluous sigset variable and calls
  * default to not require MPPE
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 arvin@suse.de
- updated to version 1.7.0
* Tue Mar 15 2005 arvin@suse.de
- updated to version 1.6.0:
  - several bug-fixes
  - add --idle-wait option
* Mon Aug  9 2004 meissner@suse.de
- Upgraded to 1.5.0:
  - fix statistics when buffering disabled [Wilson]
  - do not inherit the GRE socket [Cameron]
  - fix a case of non-shutdown of call manager [Klazes]
  - add --nobuffer option to eliminate all buffering of packets [Wilson]
  - fix corruption of command line as shown by ps [Howarth]
  - fix CPU loop after pppd killed [Cameron]
  - fix compile for ARM architecture [Hopf]
  - add documentation for command-line options [Wilson]
  - do not hang when a connection is refused [McCurdy]
  - better describe a cause of EMSGSIZE [Cameron]
* Tue Jun 22 2004 arvin@suse.de
- use new options in options.pptp
* Mon Mar  1 2004 hmacht@suse.de
- building as nonroot-user
- added patch pptp-makefile.patch because of wrong permissions
* Thu Feb 12 2004 meissner@suse.de
- Upgraded to 1.4.0:
  - support options before hostname [Wilson]
  - defer OCRQ until after SCCRP [Cameron]
  - include uninstall target [Pieter]
  - only issue a warning if sync mode is different to pppd [Klazes]
  - reformat and tidy code [Klazes]
  - reduce transmitted ack-only packets from 40%% to 0.8%% [Klazes]
* Wed Jun 11 2003 meissner@suse.de
- Upgraded to 1.3.1 bugfix release.
* Wed Jun 11 2003 meissner@suse.de
- Upgraded to 1.3.0.
* Mon May 19 2003 meissner@suse.de
- remove CVS files from install.
* Tue Feb 18 2003 meissner@suse.de
- Upgrade to upstream 1.2.0:
- fix response to dropped packets.
- fix man page, address must be before options.
- close stderr to prevent holding open ssh sessions.
- minor hint added in case of EIO on read() of pty.
- support synchronous HDLC ppp encoding. Synchronous mode results in an
  important improvement of the CPU efficiency.
- handle out-of-order packets arriving on the GRE socket by buffering.
- bind GRE socket early to prevent ICMP Unreachable response by client.
* Mon Nov 11 2002 meissner@suse.de
- initial packaging.
